==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventDetailDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        if (a.k(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
        a.ad("WebTreeSelectionOptionsEventDetail", function () { return new WebTreeSelectionOptionsEventDetailDescription(); });
        a.ac("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventDetailDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebTreeSelectionOptionsEventDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescription } from "./WebTreeSelectionOptionsEventDetailDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventDetailDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventDetailDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventDetailDescriptionMetadata.c(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
        }
        if (a.k(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("NewSelection", "Collection:WebTreeItem:WebTreeItemCollection:WebTreeItem");
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.b(a);
        a.ae("WebTreeSelectionOptionsEventDetail", function () { return new WebTreeSelectionOptionsEventDetailDescription(); });
        a.ad("WebTreeSelectionOptionsEventDetail", WebTreeSelectionOptionsEventDetailDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventDetailDescriptionMetadata, 'WebTreeSelectionOptionsEventDetailDescriptionMetadata');
    WebTreeSelectionOptionsEventDetailDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventDetailDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventDetailDescriptionMetadata };
